@@ -4,17 +4,17 @@ from termcolor import cprint
 import os.path
 
 class Checker:
-    NULL_CHAR = [".", 
-    ",", 
-    "!", 
-    ";", 
-    ":", 
-    "?", 
-    "%", 
-    "~", 
-    "+", 
-    "=", 
-    "-", 
+    NULL_CHAR = [".",
+    ",",
+    "!",
+    ";",
+    ":",
+    "?",
+    "%",
+    "~",
+    "+",
+    "=",
+    "-",
     "_",
     "*",
     "@",
@@ -42,7 +42,7 @@ class Checker:
         self.ht = None
         self.language = languageinp.lower()
         self.clean()
-        
+
     def bucketize(self):
         """
         Not something you are going to use!
@@ -65,11 +65,40 @@ class Checker:
         final_time = time.time() - start_time
         self.ht = ht
         return final_time
-    
-    def check(self):
+
+    def check(self, print=False):
+        """
+        Checks the correctness of a chunk of text in terms of spelling.
+        if print is true(which by default is false), the stats would be printed out.
+        the returned dictionary would have the structure as follows:\n
+        ```
+        statistics = {
+            
+            "total_words": int,
+
+            "misspelled_num": int,
+
+            "misspelled_words": list,
+
+            "words_in_dictionary": int,
+
+            # time spent on loading 
+            # words into the hash table
+            "load_time": float, 
+
+            # time spent on removing useless 
+            # characters for the analysis
+            "clean_time": float,
+
+            # time spent on looking up all of the words
+            "runtime": float
+
+        }
+        ```
+        """
         if not self.check_lang(self.language):
             cprint("Invalid language!", "red")
-            return 
+            return
         clean_time = self.clean()
         load_time = self.bucketize()
         buffer = self.text
@@ -86,7 +115,7 @@ class Checker:
             "load_time": load_time,
             "clean_time": clean_time
         }
-        
+
         start_time = time.time()
         wrong = 0
         for word in words:
@@ -98,7 +127,8 @@ class Checker:
         statistics["runtime"] = time.time() - start_time
         statistics["misspelled_num"] = wrong
         statistics["token"] = "47874587235697124309"
-        self.visualize(statistics)
+        if print:
+            self.visualize(statistics)
         return statistics
 
     def clean(self):
@@ -143,14 +173,17 @@ class Checker:
         res = f"Total words: {total}\nNumber of misspelled words: {wrong_num}\nNumber of words in dictionary: {dict_num}\nMisspelled words: {wrong}\nTime statistics:\nTime used to load dictionary: {lt}\nTime used to remove non-alphabetic characters: {ct}\nLookup time(s): {rt}"
         cprint(res, "green")
         return res
-        
+
 
     def check_lang(self, lang):
+        """
+        checks if the given language is supported
+        """
         supported_langs = ["english",
         "german",
         "french",
         "spanish",
         "italian"]
-        if lang not in supported_langs:
+        if lang.lower() not in supported_langs:
             return False
         return True
